==> altvmasterlist-3.2.0.tar.gz: altvmasterlist-3.2.0/README.md <==
<h3 align="center">alt:V Masterlist for Python</h3>

<div align="center">

  [![Status](https://img.shields.io/badge/status-active-success.svg)]() 
  [![License](https://img.shields.io/github/license/nickwasused/altv-python-masterlist)](/LICENSE)
  [![PyPI - Version](https://img.shields.io/pypi/v/altvmasterlist)](https://pypi.org/project/altvmasterlist/)
  [![PyPI - Format](https://img.shields.io/pypi/format/altvmasterlist)](https://pypi.org/project/altvmasterlist/)
  [![PyPI - Downloads](https://img.shields.io/pypi/dm/altvmasterlist)](https://pypi.org/project/altvmasterlist/)

</div>

---

<p align="center"> This is a python3 package to interface with the <a href="https://altv.mp">alt:V</a> Masterlist API.
    <br> 
</p>

## 📝 Table of Contents
- [About](#about)
- [Getting Started](#getting_started)
- [Deployment](#deployment)
- [Usage](#usage)
- [Built Using](#built_using)
- [Affiliation](#affiliation)

## 🧐 About <a name = "about"></a>
This is a python3 package to interface with the <a href="https://altv.mp">alt:V</a>> Masterlist API.

## 🏁 Getting Started <a name = "getting_started"></a>
These instructions will get you a copy of the project up and running on your local machine for development and testing purposes. See [deployment](#deployment) for notes on how to deploy the project on a live system.

### Prerequisites
What things you need to install the software and how to install them.

``python3`` is required.
``poetry`` [is required](https://python-poetry.org/)

### Installing

Install the required packages by running:

```
poetry install --all-extras
```

To run the tests:
```
poetry run pytest
```

To build the project:
```
poetry run build
```

## 🎈 Usage <a name="usage"></a>
None

## 🚀 Deployment <a name = "deployment"></a>
None

## Style
The code is formatted and checked with [ruff](https://github.com/astral-sh/ruff)s default settings.

## ⛏️ Built Using <a name = "built_using"></a>
- [Poetry](https://python-poetry.org/) - Python packaging and dependency management
- [Pytest](https://pytest.org/) - Code tests

## Affiliation <a name = "affiliation"></a>
I am not affiliated with the [altMP](https://alt-mp.com/) team.

==> altvmasterlist-3.2.3.tar.gz: altvmasterlist-3.2.3/README.md <==
<h3 align="center">alt:V Masterlist for Python</h3>

<div align="center">

  [![Status](https://img.shields.io/badge/status-active-success.svg)]() 
  [![License](https://img.shields.io/github/license/nickwasused/altv-python-masterlist)](/LICENSE)
  [![PyPI - Version](https://img.shields.io/pypi/v/altvmasterlist)](https://pypi.org/project/altvmasterlist/)
  [![PyPI - Format](https://img.shields.io/pypi/format/altvmasterlist)](https://pypi.org/project/altvmasterlist/)
  [![PyPI - Downloads](https://img.shields.io/pypi/dm/altvmasterlist)](https://pypi.org/project/altvmasterlist/)

</div>

---

<p align="center"> This is a python3 package to interface with the <a href="https://altv.mp">alt:V</a> Masterlist API.
    <br> 
</p>

## 📝 Table of Contents
- [About](#about)
- [Getting Started](#getting_started)
- [Deployment](#deployment)
- [Usage](#usage)
- [Built Using](#built_using)
- [Affiliation](#affiliation)

## 🧐 About <a name = "about"></a>
This is a python3 package to interface with the <a href="https://altv.mp">alt:V</a> Masterlist API.

## 🏁 Getting Started <a name = "getting_started"></a>
These instructions will get you a copy of the project up and running on your local machine for development and testing purposes. See [deployment](#deployment) for notes on how to deploy the project on a live system.

### Prerequisites
What things you need to install the software and how to install them.

``python3`` is required.
``poetry`` [is required](https://python-poetry.org/)

### Installing

Install the required packages by running:

```
poetry install --all-extras
```

To run the tests:
```
poetry run pytest
```

To build the project:
```
poetry run build
```

## 🎈 Usage <a name="usage"></a>
See the docs: [https://nickwasused.com/altv-python-masterlist/altvmasterlist.html](https://nickwasused.com/altv-python-masterlist/altvmasterlist.html)

## 🚀 Deployment <a name = "deployment"></a>
None

## Style
The code is formatted and checked with [ruff](https://github.com/astral-sh/ruff)s default settings.

## ⛏️ Built Using <a name = "built_using"></a>
- [Poetry](https://python-poetry.org/) - Python packaging and dependency management
- [Pytest](https://pytest.org/) - Code tests

## Affiliation <a name = "affiliation"></a>
I am not affiliated with the [altMP](https://alt-mp.com/) team.
